# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dapr/dapr.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dapr/dapr.proto',
  package='dapr',
  syntax='proto3',
  serialized_options=_b('\n\007io.daprB\nDaprProtos'),
  serialized_pb=_b('\n\x0f\x64\x61pr/dapr.proto\x12\x04\x64\x61pr\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\"\xb9\x01\n\x1dInvokeServiceResponseEnvelope\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x43\n\x08metadata\x18\x02 \x03(\x0b\x32\x31.dapr.InvokeServiceResponseEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x13\x44\x65leteStateEnvelope\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12#\n\x07options\x18\x03 \x01(\x0b\x32\x12.dapr.StateOptions\"9\n\x11SaveStateEnvelope\x12$\n\x08requests\x18\x01 \x03(\x0b\x32\x12.dapr.StateRequest\"4\n\x10GetStateEnvelope\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsistency\x18\x02 \x01(\t\"L\n\x18GetStateResponseEnvelope\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\"\xb7\x01\n\x15InvokeBindingEnvelope\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12;\n\x08metadata\x18\x03 \x03(\x0b\x32).dapr.InvokeBindingEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x01\n\x15InvokeServiceEnvelope\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\x12;\n\x08metadata\x18\x04 \x03(\x0b\x32).dapr.InvokeServiceEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x14PublishEventEnvelope\x12\r\n\x05topic\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\xca\x01\n\x05State\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12+\n\x08metadata\x18\x04 \x03(\x0b\x32\x19.dapr.State.MetadataEntry\x12#\n\x07options\x18\x05 \x01(\x0b\x32\x12.dapr.StateOptions\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x0cStateOptions\x12\x13\n\x0b\x63oncurrency\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsistency\x18\x02 \x01(\t\x12&\n\x0bretryPolicy\x18\x03 \x01(\x0b\x32\x11.dapr.RetryPolicy\"^\n\x0bRetryPolicy\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12+\n\x08interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xdf\x01\n\x0cStateRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x32\n\x08metadata\x18\x04 \x03(\x0b\x32 .dapr.StateRequest.MetadataEntry\x12*\n\x07options\x18\x05 \x01(\x0b\x32\x19.dapr.StateRequestOptions\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x13StateRequestOptions\x12\x13\n\x0b\x63oncurrency\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsistency\x18\x02 \x01(\t\x12+\n\x0bretryPolicy\x18\x03 \x01(\x0b\x32\x16.dapr.StateRetryPolicy\"c\n\x10StateRetryPolicy\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12+\n\x08interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration2\xb3\x03\n\x04\x44\x61pr\x12\x44\n\x0cPublishEvent\x12\x1a.dapr.PublishEventEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x12S\n\rInvokeService\x12\x1b.dapr.InvokeServiceEnvelope\x1a#.dapr.InvokeServiceResponseEnvelope\"\x00\x12\x46\n\rInvokeBinding\x12\x1b.dapr.InvokeBindingEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x12\x44\n\x08GetState\x12\x16.dapr.GetStateEnvelope\x1a\x1e.dapr.GetStateResponseEnvelope\"\x00\x12>\n\tSaveState\x12\x17.dapr.SaveStateEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x12\x42\n\x0b\x44\x65leteState\x12\x19.dapr.DeleteStateEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x42\x15\n\x07io.daprB\nDaprProtosb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_INVOKESERVICERESPONSEENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.InvokeServiceResponseEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.InvokeServiceResponseEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.InvokeServiceResponseEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_INVOKESERVICERESPONSEENVELOPE = _descriptor.Descriptor(
  name='InvokeServiceResponseEnvelope',
  full_name='dapr.InvokeServiceResponseEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.InvokeServiceResponseEnvelope.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.InvokeServiceResponseEnvelope.metadata', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOKESERVICERESPONSEENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=299,
)


_DELETESTATEENVELOPE = _descriptor.Descriptor(
  name='DeleteStateEnvelope',
  full_name='dapr.DeleteStateEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.DeleteStateEnvelope.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='dapr.DeleteStateEnvelope.etag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='dapr.DeleteStateEnvelope.options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=386,
)


_SAVESTATEENVELOPE = _descriptor.Descriptor(
  name='SaveStateEnvelope',
  full_name='dapr.SaveStateEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='requests', full_name='dapr.SaveStateEnvelope.requests', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=388,
  serialized_end=445,
)


_GETSTATEENVELOPE = _descriptor.Descriptor(
  name='GetStateEnvelope',
  full_name='dapr.GetStateEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.GetStateEnvelope.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consistency', full_name='dapr.GetStateEnvelope.consistency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=499,
)


_GETSTATERESPONSEENVELOPE = _descriptor.Descriptor(
  name='GetStateResponseEnvelope',
  full_name='dapr.GetStateResponseEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.GetStateResponseEnvelope.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='dapr.GetStateResponseEnvelope.etag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=577,
)


_INVOKEBINDINGENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.InvokeBindingEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.InvokeBindingEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.InvokeBindingEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_INVOKEBINDINGENVELOPE = _descriptor.Descriptor(
  name='InvokeBindingEnvelope',
  full_name='dapr.InvokeBindingEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='dapr.InvokeBindingEnvelope.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.InvokeBindingEnvelope.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.InvokeBindingEnvelope.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOKEBINDINGENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=580,
  serialized_end=763,
)


_INVOKESERVICEENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.InvokeServiceEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.InvokeServiceEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.InvokeServiceEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_INVOKESERVICEENVELOPE = _descriptor.Descriptor(
  name='InvokeServiceEnvelope',
  full_name='dapr.InvokeServiceEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='dapr.InvokeServiceEnvelope.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='dapr.InvokeServiceEnvelope.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.InvokeServiceEnvelope.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.InvokeServiceEnvelope.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOKESERVICEENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=963,
)


_PUBLISHEVENTENVELOPE = _descriptor.Descriptor(
  name='PublishEventEnvelope',
  full_name='dapr.PublishEventEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='dapr.PublishEventEnvelope.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='dapr.PublishEventEnvelope.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=965,
  serialized_end=1038,
)


_STATE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.State.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.State.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.State.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_STATE = _descriptor.Descriptor(
  name='State',
  full_name='dapr.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.State.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.State.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='dapr.State.etag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.State.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='dapr.State.options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1243,
)


_STATEOPTIONS = _descriptor.Descriptor(
  name='StateOptions',
  full_name='dapr.StateOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='dapr.StateOptions.concurrency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consistency', full_name='dapr.StateOptions.consistency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retryPolicy', full_name='dapr.StateOptions.retryPolicy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1245,
  serialized_end=1341,
)


_RETRYPOLICY = _descriptor.Descriptor(
  name='RetryPolicy',
  full_name='dapr.RetryPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='dapr.RetryPolicy.threshold', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='dapr.RetryPolicy.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='dapr.RetryPolicy.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1343,
  serialized_end=1437,
)


_STATEREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='dapr.StateRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.StateRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.StateRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=299,
)

_STATEREQUEST = _descriptor.Descriptor(
  name='StateRequest',
  full_name='dapr.StateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='dapr.StateRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='dapr.StateRequest.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='dapr.StateRequest.etag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='dapr.StateRequest.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='dapr.StateRequest.options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATEREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1440,
  serialized_end=1663,
)


_STATEREQUESTOPTIONS = _descriptor.Descriptor(
  name='StateRequestOptions',
  full_name='dapr.StateRequestOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='dapr.StateRequestOptions.concurrency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consistency', full_name='dapr.StateRequestOptions.consistency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retryPolicy', full_name='dapr.StateRequestOptions.retryPolicy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1665,
  serialized_end=1773,
)


_STATERETRYPOLICY = _descriptor.Descriptor(
  name='StateRetryPolicy',
  full_name='dapr.StateRetryPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='dapr.StateRetryPolicy.threshold', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='dapr.StateRetryPolicy.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='dapr.StateRetryPolicy.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1775,
  serialized_end=1874,
)

_INVOKESERVICERESPONSEENVELOPE_METADATAENTRY.containing_type = _INVOKESERVICERESPONSEENVELOPE
_INVOKESERVICERESPONSEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKESERVICERESPONSEENVELOPE.fields_by_name['metadata'].message_type = _INVOKESERVICERESPONSEENVELOPE_METADATAENTRY
_DELETESTATEENVELOPE.fields_by_name['options'].message_type = _STATEOPTIONS
_SAVESTATEENVELOPE.fields_by_name['requests'].message_type = _STATEREQUEST
_GETSTATERESPONSEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKEBINDINGENVELOPE_METADATAENTRY.containing_type = _INVOKEBINDINGENVELOPE
_INVOKEBINDINGENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKEBINDINGENVELOPE.fields_by_name['metadata'].message_type = _INVOKEBINDINGENVELOPE_METADATAENTRY
_INVOKESERVICEENVELOPE_METADATAENTRY.containing_type = _INVOKESERVICEENVELOPE
_INVOKESERVICEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKESERVICEENVELOPE.fields_by_name['metadata'].message_type = _INVOKESERVICEENVELOPE_METADATAENTRY
_PUBLISHEVENTENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATE_METADATAENTRY.containing_type = _STATE
_STATE.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATE.fields_by_name['metadata'].message_type = _STATE_METADATAENTRY
_STATE.fields_by_name['options'].message_type = _STATEOPTIONS
_STATEOPTIONS.fields_by_name['retryPolicy'].message_type = _RETRYPOLICY
_RETRYPOLICY.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_STATEREQUEST_METADATAENTRY.containing_type = _STATEREQUEST
_STATEREQUEST.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATEREQUEST.fields_by_name['metadata'].message_type = _STATEREQUEST_METADATAENTRY
_STATEREQUEST.fields_by_name['options'].message_type = _STATEREQUESTOPTIONS
_STATEREQUESTOPTIONS.fields_by_name['retryPolicy'].message_type = _STATERETRYPOLICY
_STATERETRYPOLICY.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['InvokeServiceResponseEnvelope'] = _INVOKESERVICERESPONSEENVELOPE
DESCRIPTOR.message_types_by_name['DeleteStateEnvelope'] = _DELETESTATEENVELOPE
DESCRIPTOR.message_types_by_name['SaveStateEnvelope'] = _SAVESTATEENVELOPE
DESCRIPTOR.message_types_by_name['GetStateEnvelope'] = _GETSTATEENVELOPE
DESCRIPTOR.message_types_by_name['GetStateResponseEnvelope'] = _GETSTATERESPONSEENVELOPE
DESCRIPTOR.message_types_by_name['InvokeBindingEnvelope'] = _INVOKEBINDINGENVELOPE
DESCRIPTOR.message_types_by_name['InvokeServiceEnvelope'] = _INVOKESERVICEENVELOPE
DESCRIPTOR.message_types_by_name['PublishEventEnvelope'] = _PUBLISHEVENTENVELOPE
DESCRIPTOR.message_types_by_name['State'] = _STATE
DESCRIPTOR.message_types_by_name['StateOptions'] = _STATEOPTIONS
DESCRIPTOR.message_types_by_name['RetryPolicy'] = _RETRYPOLICY
DESCRIPTOR.message_types_by_name['StateRequest'] = _STATEREQUEST
DESCRIPTOR.message_types_by_name['StateRequestOptions'] = _STATEREQUESTOPTIONS
DESCRIPTOR.message_types_by_name['StateRetryPolicy'] = _STATERETRYPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InvokeServiceResponseEnvelope = _reflection.GeneratedProtocolMessageType('InvokeServiceResponseEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKESERVICERESPONSEENVELOPE_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.InvokeServiceResponseEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKESERVICERESPONSEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.InvokeServiceResponseEnvelope)
  })
_sym_db.RegisterMessage(InvokeServiceResponseEnvelope)
_sym_db.RegisterMessage(InvokeServiceResponseEnvelope.MetadataEntry)

DeleteStateEnvelope = _reflection.GeneratedProtocolMessageType('DeleteStateEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTATEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.DeleteStateEnvelope)
  })
_sym_db.RegisterMessage(DeleteStateEnvelope)

SaveStateEnvelope = _reflection.GeneratedProtocolMessageType('SaveStateEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _SAVESTATEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.SaveStateEnvelope)
  })
_sym_db.RegisterMessage(SaveStateEnvelope)

GetStateEnvelope = _reflection.GeneratedProtocolMessageType('GetStateEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.GetStateEnvelope)
  })
_sym_db.RegisterMessage(GetStateEnvelope)

GetStateResponseEnvelope = _reflection.GeneratedProtocolMessageType('GetStateResponseEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATERESPONSEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.GetStateResponseEnvelope)
  })
_sym_db.RegisterMessage(GetStateResponseEnvelope)

InvokeBindingEnvelope = _reflection.GeneratedProtocolMessageType('InvokeBindingEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKEBINDINGENVELOPE_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.InvokeBindingEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKEBINDINGENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.InvokeBindingEnvelope)
  })
_sym_db.RegisterMessage(InvokeBindingEnvelope)
_sym_db.RegisterMessage(InvokeBindingEnvelope.MetadataEntry)

InvokeServiceEnvelope = _reflection.GeneratedProtocolMessageType('InvokeServiceEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKESERVICEENVELOPE_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.InvokeServiceEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKESERVICEENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.InvokeServiceEnvelope)
  })
_sym_db.RegisterMessage(InvokeServiceEnvelope)
_sym_db.RegisterMessage(InvokeServiceEnvelope.MetadataEntry)

PublishEventEnvelope = _reflection.GeneratedProtocolMessageType('PublishEventEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHEVENTENVELOPE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.PublishEventEnvelope)
  })
_sym_db.RegisterMessage(PublishEventEnvelope)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATE_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.State.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _STATE,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.State)
  })
_sym_db.RegisterMessage(State)
_sym_db.RegisterMessage(State.MetadataEntry)

StateOptions = _reflection.GeneratedProtocolMessageType('StateOptions', (_message.Message,), {
  'DESCRIPTOR' : _STATEOPTIONS,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.StateOptions)
  })
_sym_db.RegisterMessage(StateOptions)

RetryPolicy = _reflection.GeneratedProtocolMessageType('RetryPolicy', (_message.Message,), {
  'DESCRIPTOR' : _RETRYPOLICY,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.RetryPolicy)
  })
_sym_db.RegisterMessage(RetryPolicy)

StateRequest = _reflection.GeneratedProtocolMessageType('StateRequest', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATEREQUEST_METADATAENTRY,
    '__module__' : 'dapr.dapr_pb2'
    # @@protoc_insertion_point(class_scope:dapr.StateRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _STATEREQUEST,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.StateRequest)
  })
_sym_db.RegisterMessage(StateRequest)
_sym_db.RegisterMessage(StateRequest.MetadataEntry)

StateRequestOptions = _reflection.GeneratedProtocolMessageType('StateRequestOptions', (_message.Message,), {
  'DESCRIPTOR' : _STATEREQUESTOPTIONS,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.StateRequestOptions)
  })
_sym_db.RegisterMessage(StateRequestOptions)

StateRetryPolicy = _reflection.GeneratedProtocolMessageType('StateRetryPolicy', (_message.Message,), {
  'DESCRIPTOR' : _STATERETRYPOLICY,
  '__module__' : 'dapr.dapr_pb2'
  # @@protoc_insertion_point(class_scope:dapr.StateRetryPolicy)
  })
_sym_db.RegisterMessage(StateRetryPolicy)


DESCRIPTOR._options = None
_INVOKESERVICERESPONSEENVELOPE_METADATAENTRY._options = None
_INVOKEBINDINGENVELOPE_METADATAENTRY._options = None
_INVOKESERVICEENVELOPE_METADATAENTRY._options = None
_STATE_METADATAENTRY._options = None
_STATEREQUEST_METADATAENTRY._options = None

_DAPR = _descriptor.ServiceDescriptor(
  name='Dapr',
  full_name='dapr.Dapr',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1877,
  serialized_end=2312,
  methods=[
  _descriptor.MethodDescriptor(
    name='PublishEvent',
    full_name='dapr.Dapr.PublishEvent',
    index=0,
    containing_service=None,
    input_type=_PUBLISHEVENTENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InvokeService',
    full_name='dapr.Dapr.InvokeService',
    index=1,
    containing_service=None,
    input_type=_INVOKESERVICEENVELOPE,
    output_type=_INVOKESERVICERESPONSEENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InvokeBinding',
    full_name='dapr.Dapr.InvokeBinding',
    index=2,
    containing_service=None,
    input_type=_INVOKEBINDINGENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetState',
    full_name='dapr.Dapr.GetState',
    index=3,
    containing_service=None,
    input_type=_GETSTATEENVELOPE,
    output_type=_GETSTATERESPONSEENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SaveState',
    full_name='dapr.Dapr.SaveState',
    index=4,
    containing_service=None,
    input_type=_SAVESTATEENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteState',
    full_name='dapr.Dapr.DeleteState',
    index=5,
    containing_service=None,
    input_type=_DELETESTATEENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAPR)

DESCRIPTOR.services_by_name['Dapr'] = _DAPR

# @@protoc_insertion_point(module_scope)
