# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: daprclient/daprclient.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='daprclient/daprclient.proto',
  package='daprclient',
  syntax='proto3',
  serialized_options=_b('\n\007io.daprB\020DaprClientProtos'),
  serialized_pb=_b('\n\x1b\x64\x61prclient/daprclient.proto\x12\ndaprclient\x1a\x19google/protobuf/any.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/duration.proto\"\x9f\x01\n\x12\x43loudEventEnvelope\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0bspecVersion\x18\x04 \x01(\t\x12\x17\n\x0f\x64\x61taContentType\x18\x05 \x01(\t\x12\r\n\x05topic\x18\x06 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\"\xbb\x01\n\x14\x42indingEventEnvelope\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12@\n\x08metadata\x18\x03 \x03(\x0b\x32..daprclient.BindingEventEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\x17\x42indingResponseEnvelope\x12\"\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\n\n\x02to\x18\x02 \x03(\t\x12 \n\x05state\x18\x03 \x03(\x0b\x32\x11.daprclient.State\x12\x13\n\x0b\x63oncurrency\x18\x04 \x01(\t\"\xb1\x01\n\x0eInvokeEnvelope\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12:\n\x08metadata\x18\x03 \x03(\x0b\x32(.daprclient.InvokeEnvelope.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\x1dGetTopicSubscriptionsEnvelope\x12\x0e\n\x06topics\x18\x01 \x03(\t\"4\n GetBindingsSubscriptionsEnvelope\x12\x10\n\x08\x62indings\x18\x01 \x03(\t\"\xd6\x01\n\x05State\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\x31\n\x08metadata\x18\x04 \x03(\x0b\x32\x1f.daprclient.State.MetadataEntry\x12)\n\x07options\x18\x05 \x01(\x0b\x32\x18.daprclient.StateOptions\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x0cStateOptions\x12\x13\n\x0b\x63oncurrency\x18\x01 \x01(\t\x12\x13\n\x0b\x63onsistency\x18\x02 \x01(\t\x12,\n\x0bretryPolicy\x18\x03 \x01(\x0b\x32\x17.daprclient.RetryPolicy\"^\n\x0bRetryPolicy\x12\x11\n\tthreshold\x18\x01 \x01(\x05\x12\x0f\n\x07pattern\x18\x02 \x01(\t\x12+\n\x08interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration2\xb3\x03\n\nDaprClient\x12>\n\x08OnInvoke\x12\x1a.daprclient.InvokeEnvelope\x1a\x14.google.protobuf.Any\"\x00\x12\\\n\x15GetTopicSubscriptions\x12\x16.google.protobuf.Empty\x1a).daprclient.GetTopicSubscriptionsEnvelope\"\x00\x12\x62\n\x18GetBindingsSubscriptions\x12\x16.google.protobuf.Empty\x1a,.daprclient.GetBindingsSubscriptionsEnvelope\"\x00\x12Y\n\x0eOnBindingEvent\x12 .daprclient.BindingEventEnvelope\x1a#.daprclient.BindingResponseEnvelope\"\x00\x12H\n\x0cOnTopicEvent\x12\x1e.daprclient.CloudEventEnvelope\x1a\x16.google.protobuf.Empty\"\x00\x42\x1b\n\x07io.daprB\x10\x44\x61prClientProtosb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,])




_CLOUDEVENTENVELOPE = _descriptor.Descriptor(
  name='CloudEventEnvelope',
  full_name='daprclient.CloudEventEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='daprclient.CloudEventEnvelope.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='daprclient.CloudEventEnvelope.source', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='daprclient.CloudEventEnvelope.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='specVersion', full_name='daprclient.CloudEventEnvelope.specVersion', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataContentType', full_name='daprclient.CloudEventEnvelope.dataContentType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='topic', full_name='daprclient.CloudEventEnvelope.topic', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='daprclient.CloudEventEnvelope.data', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=291,
)


_BINDINGEVENTENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='daprclient.BindingEventEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='daprclient.BindingEventEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='daprclient.BindingEventEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=481,
)

_BINDINGEVENTENVELOPE = _descriptor.Descriptor(
  name='BindingEventEnvelope',
  full_name='daprclient.BindingEventEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='daprclient.BindingEventEnvelope.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='daprclient.BindingEventEnvelope.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='daprclient.BindingEventEnvelope.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BINDINGEVENTENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=481,
)


_BINDINGRESPONSEENVELOPE = _descriptor.Descriptor(
  name='BindingResponseEnvelope',
  full_name='daprclient.BindingResponseEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='daprclient.BindingResponseEnvelope.data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='to', full_name='daprclient.BindingResponseEnvelope.to', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='daprclient.BindingResponseEnvelope.state', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='daprclient.BindingResponseEnvelope.concurrency', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=612,
)


_INVOKEENVELOPE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='daprclient.InvokeEnvelope.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='daprclient.InvokeEnvelope.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='daprclient.InvokeEnvelope.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=481,
)

_INVOKEENVELOPE = _descriptor.Descriptor(
  name='InvokeEnvelope',
  full_name='daprclient.InvokeEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='daprclient.InvokeEnvelope.method', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='daprclient.InvokeEnvelope.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='daprclient.InvokeEnvelope.metadata', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_INVOKEENVELOPE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=615,
  serialized_end=792,
)


_GETTOPICSUBSCRIPTIONSENVELOPE = _descriptor.Descriptor(
  name='GetTopicSubscriptionsEnvelope',
  full_name='daprclient.GetTopicSubscriptionsEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topics', full_name='daprclient.GetTopicSubscriptionsEnvelope.topics', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=794,
  serialized_end=841,
)


_GETBINDINGSSUBSCRIPTIONSENVELOPE = _descriptor.Descriptor(
  name='GetBindingsSubscriptionsEnvelope',
  full_name='daprclient.GetBindingsSubscriptionsEnvelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bindings', full_name='daprclient.GetBindingsSubscriptionsEnvelope.bindings', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=843,
  serialized_end=895,
)


_STATE_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='daprclient.State.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='daprclient.State.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='daprclient.State.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=434,
  serialized_end=481,
)

_STATE = _descriptor.Descriptor(
  name='State',
  full_name='daprclient.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='daprclient.State.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='daprclient.State.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='etag', full_name='daprclient.State.etag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='daprclient.State.metadata', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='daprclient.State.options', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATE_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=898,
  serialized_end=1112,
)


_STATEOPTIONS = _descriptor.Descriptor(
  name='StateOptions',
  full_name='daprclient.StateOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='concurrency', full_name='daprclient.StateOptions.concurrency', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='consistency', full_name='daprclient.StateOptions.consistency', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retryPolicy', full_name='daprclient.StateOptions.retryPolicy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1114,
  serialized_end=1216,
)


_RETRYPOLICY = _descriptor.Descriptor(
  name='RetryPolicy',
  full_name='daprclient.RetryPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threshold', full_name='daprclient.RetryPolicy.threshold', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pattern', full_name='daprclient.RetryPolicy.pattern', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='daprclient.RetryPolicy.interval', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1218,
  serialized_end=1312,
)

_CLOUDEVENTENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_BINDINGEVENTENVELOPE_METADATAENTRY.containing_type = _BINDINGEVENTENVELOPE
_BINDINGEVENTENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_BINDINGEVENTENVELOPE.fields_by_name['metadata'].message_type = _BINDINGEVENTENVELOPE_METADATAENTRY
_BINDINGRESPONSEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_BINDINGRESPONSEENVELOPE.fields_by_name['state'].message_type = _STATE
_INVOKEENVELOPE_METADATAENTRY.containing_type = _INVOKEENVELOPE
_INVOKEENVELOPE.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_INVOKEENVELOPE.fields_by_name['metadata'].message_type = _INVOKEENVELOPE_METADATAENTRY
_STATE_METADATAENTRY.containing_type = _STATE
_STATE.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_STATE.fields_by_name['metadata'].message_type = _STATE_METADATAENTRY
_STATE.fields_by_name['options'].message_type = _STATEOPTIONS
_STATEOPTIONS.fields_by_name['retryPolicy'].message_type = _RETRYPOLICY
_RETRYPOLICY.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['CloudEventEnvelope'] = _CLOUDEVENTENVELOPE
DESCRIPTOR.message_types_by_name['BindingEventEnvelope'] = _BINDINGEVENTENVELOPE
DESCRIPTOR.message_types_by_name['BindingResponseEnvelope'] = _BINDINGRESPONSEENVELOPE
DESCRIPTOR.message_types_by_name['InvokeEnvelope'] = _INVOKEENVELOPE
DESCRIPTOR.message_types_by_name['GetTopicSubscriptionsEnvelope'] = _GETTOPICSUBSCRIPTIONSENVELOPE
DESCRIPTOR.message_types_by_name['GetBindingsSubscriptionsEnvelope'] = _GETBINDINGSSUBSCRIPTIONSENVELOPE
DESCRIPTOR.message_types_by_name['State'] = _STATE
DESCRIPTOR.message_types_by_name['StateOptions'] = _STATEOPTIONS
DESCRIPTOR.message_types_by_name['RetryPolicy'] = _RETRYPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CloudEventEnvelope = _reflection.GeneratedProtocolMessageType('CloudEventEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDEVENTENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.CloudEventEnvelope)
  })
_sym_db.RegisterMessage(CloudEventEnvelope)

BindingEventEnvelope = _reflection.GeneratedProtocolMessageType('BindingEventEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _BINDINGEVENTENVELOPE_METADATAENTRY,
    '__module__' : 'daprclient.daprclient_pb2'
    # @@protoc_insertion_point(class_scope:daprclient.BindingEventEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _BINDINGEVENTENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.BindingEventEnvelope)
  })
_sym_db.RegisterMessage(BindingEventEnvelope)
_sym_db.RegisterMessage(BindingEventEnvelope.MetadataEntry)

BindingResponseEnvelope = _reflection.GeneratedProtocolMessageType('BindingResponseEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _BINDINGRESPONSEENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.BindingResponseEnvelope)
  })
_sym_db.RegisterMessage(BindingResponseEnvelope)

InvokeEnvelope = _reflection.GeneratedProtocolMessageType('InvokeEnvelope', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVOKEENVELOPE_METADATAENTRY,
    '__module__' : 'daprclient.daprclient_pb2'
    # @@protoc_insertion_point(class_scope:daprclient.InvokeEnvelope.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _INVOKEENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.InvokeEnvelope)
  })
_sym_db.RegisterMessage(InvokeEnvelope)
_sym_db.RegisterMessage(InvokeEnvelope.MetadataEntry)

GetTopicSubscriptionsEnvelope = _reflection.GeneratedProtocolMessageType('GetTopicSubscriptionsEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPICSUBSCRIPTIONSENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.GetTopicSubscriptionsEnvelope)
  })
_sym_db.RegisterMessage(GetTopicSubscriptionsEnvelope)

GetBindingsSubscriptionsEnvelope = _reflection.GeneratedProtocolMessageType('GetBindingsSubscriptionsEnvelope', (_message.Message,), {
  'DESCRIPTOR' : _GETBINDINGSSUBSCRIPTIONSENVELOPE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.GetBindingsSubscriptionsEnvelope)
  })
_sym_db.RegisterMessage(GetBindingsSubscriptionsEnvelope)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATE_METADATAENTRY,
    '__module__' : 'daprclient.daprclient_pb2'
    # @@protoc_insertion_point(class_scope:daprclient.State.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _STATE,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.State)
  })
_sym_db.RegisterMessage(State)
_sym_db.RegisterMessage(State.MetadataEntry)

StateOptions = _reflection.GeneratedProtocolMessageType('StateOptions', (_message.Message,), {
  'DESCRIPTOR' : _STATEOPTIONS,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.StateOptions)
  })
_sym_db.RegisterMessage(StateOptions)

RetryPolicy = _reflection.GeneratedProtocolMessageType('RetryPolicy', (_message.Message,), {
  'DESCRIPTOR' : _RETRYPOLICY,
  '__module__' : 'daprclient.daprclient_pb2'
  # @@protoc_insertion_point(class_scope:daprclient.RetryPolicy)
  })
_sym_db.RegisterMessage(RetryPolicy)


DESCRIPTOR._options = None
_BINDINGEVENTENVELOPE_METADATAENTRY._options = None
_INVOKEENVELOPE_METADATAENTRY._options = None
_STATE_METADATAENTRY._options = None

_DAPRCLIENT = _descriptor.ServiceDescriptor(
  name='DaprClient',
  full_name='daprclient.DaprClient',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1315,
  serialized_end=1750,
  methods=[
  _descriptor.MethodDescriptor(
    name='OnInvoke',
    full_name='daprclient.DaprClient.OnInvoke',
    index=0,
    containing_service=None,
    input_type=_INVOKEENVELOPE,
    output_type=google_dot_protobuf_dot_any__pb2._ANY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTopicSubscriptions',
    full_name='daprclient.DaprClient.GetTopicSubscriptions',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETTOPICSUBSCRIPTIONSENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetBindingsSubscriptions',
    full_name='daprclient.DaprClient.GetBindingsSubscriptions',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETBINDINGSSUBSCRIPTIONSENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OnBindingEvent',
    full_name='daprclient.DaprClient.OnBindingEvent',
    index=3,
    containing_service=None,
    input_type=_BINDINGEVENTENVELOPE,
    output_type=_BINDINGRESPONSEENVELOPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='OnTopicEvent',
    full_name='daprclient.DaprClient.OnTopicEvent',
    index=4,
    containing_service=None,
    input_type=_CLOUDEVENTENVELOPE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAPRCLIENT)

DESCRIPTOR.services_by_name['DaprClient'] = _DAPRCLIENT

# @@protoc_insertion_point(module_scope)
